gengetopt: getopt_long parser generator
===========================================

Description
-----------

GNU Gengetopt converts a textual description of your program's
arguments and options into a getopt_long() parser in C (or C++).

Website: https://www.gnu.org/software/gengetopt/


License
-------
GPL-3+ (https://www.gnu.org/software/gengetopt/LICENSE)
